repoze.debug README
===================

Middleware which can help with in-production forensic debugging.

Installation
------------

Install using setuptools, e.g. (within a virtualenv)::

 $ easy_install repoze.debug


Usage
-----

For details on using the various components, please see the
documentation in ``docs/index.rst``.  A rendered version of that documentation
is also available online:

 - http://docs.repoze.org/debug


Reporting Bugs 
--------------

Please report bugs in this package to

  https://github.com/repoze/repoze.debug/issues


Obtaining Source Code
---------------------

Download development or tagged versions of the software by visiting:

  https://github.com/repoze/repoze.debug

